## 流程
步骤：
1：阅读指定的文件
2：根据后续步骤，将所有需要生成的方法写在server文件夹下的manage.event.ts文件中，如果文件已存在就在追加写入，如果文件不存在就新建写入
3：找到需要阅读的文件中带有 #[rpc=rpcServer,src=*,rpcWrapper=xxxx,rpcMode=xxx] 注释的方法,下方是需要找出的方法样例
```ts
//例子: 以game_train_room库中的方法为例

// #[rpc=rpcServer,src=*,rpcWrapper=write,rpcMode=remote] 占据修炼塔
export const seizeRoom = async (tr: Tr, rid: number, site: number) =>{}

// #[rpc=rpcServer,src=*,rpcWrapper=read,rpcMode=check] 查看修炼塔整体信息
export const showAllRoom = async (tr: Tr, rid: number) => {}
```
4：给找到的目标方法进行需求方法生成，下方为例子，该例子中展示了如何对找到的方法进行需求方法的生成
注意：如果方法有结构体参数，需要根据导入的结构体样式里面的值对arg进行传值
注意：导入路径需要绝对路径，导入后不需要去处理导入路径找不到的问题
```ts
//例子: 以game_train_room库中的方法为例，这部分为找到的需要进行方法生成的目标

// #[event=game_train_room_seizeRoom, src=pid_rpc, management_plugin_name=game_train_room, auth=rw] 
export const TestSeizeRoom = async (_eventName: string, arg: any) => {
        await env.dbMgr.write(async (tr: Tr) => {//注意：如果找到的方法rpcWrapper的值为write,env.dbMgr.xx,xx就应该为write
        return await seizeRoom(tr,Number(arg.rid),Number(arg.site));//如果有其他值需要通过arg传入
    });
}

// #[event=game_train_room_showAllRoom, src=pid_rpc, management_plugin_name=game_train_room, auth=rw] 
export const TestShowAllRoom = async (_eventName: string, arg: any) => {
        await env.dbMgr.read(async (tr: Tr) => {//注意：如果找到的方法rpcWrapper的值为read,env.dbMgr.xx,xx就应该为read
        return await showAllRoom(tr,Number(arg.rid));//如果有其他值需要通过arg传入
    });
}
```
5：下面为函数参数有结构体的方法处理方法
```ts
//例子：已game_bahuang_lode库为例，库中有第三个参数为自定义的结构体，就需要通过game_bahuang_lode(库名)找到参数的定义，对包含的值进行new和赋值
import { gatherArg, stopArg,gatherDetail } from "game_bahuang_lode/struct/param.struct";

// #[rpc=rpcServer,src=*,rpcWrapper=write,rpcMode=remote] 这个方法为找到的方法
export const stopGatherRefreshLode = async (tr: Tr, rid: number, arg: stopArg)=>{}

// 函数的第三参是中其他文件中导入进来的，需要找出该结构体的所有key并进行赋值
// #[event=game_bahuang_lode_stopGatherRefreshLode, src=pid_rpc, management_plugin_name=game_bahuang_lode, auth=rw]
export const TestStopGatherRefreshLode = async (_eventName: string, arg: any) => {
    await env.dbMgr.write(async (tr: Tr) => {
            let param = new stopArg();
            //stopArg中包含的key为list，list是个数字数组
            param.list = arg.list;//需要将值转换为正确的类型
            return await stopGatherRefreshLode(tr,Number(arg.rid),param);
    });
};


// #[rpc=rpcServer,src=*,rpcWrapper=write,rpcMode=remote] 这个方法为找到的方法
export const gatherRefreshLode = async (tr: Tr, rid: number, arg: gatherArg) => {}

// #[event=game_bahuang_lode_gatherRefreshLode, src=pid_rpc, management_plugin_name=game_bahuang_lode, auth=rw]
export const TestGatherRefreshLode = async (_eventName: string, arg: any) => {
    await env.dbMgr.write(async (tr: Tr) => {
        let list = [];
        let listValue = new gatherDetail();
        //gatherDetail中有4个key，每个key对应的value需要的数据类型从"game_bahuang_lode/struct/param.struct"中读取
        listValue.mapID = arg.mapID;
        listValue.lodeID = arg.lodeID;
        listValue.teamNo = arg.teamNo;
        listValue.place = arg.place;
        list.push(listValue);
        let param = new gatherArg();//注意：gatherArg这个参数类型中的value不是基础数据类型，是gatherDetail这种结构体，需要通过上面的处理并导入到目标文件
        param.list = list;
        return await gatherRefreshLode(tr, Number(arg.rid), param);
    });
};
```

## 样例 在game_bahuang_lode库下生成
```ts
import { Tr } from 'pi_ucore/db/mgr';
import { Env } from 'pi_ucore/db/env';
import { stopArg } from 'game_bahuang_lode/struct/param.struct';
import { stopGatherRefreshLode } from 'game_bahuang_lode/server/rpc.event'

declare var env: Env;

// #[rpc=rpcServer,src=*,rpcWrapper=write,rpcMode=remote] 
export const stopGatherRefreshLode = async (tr: Tr, rid: number, arg: stopArg)=>{};//这是第2步中找到的方法


// #[event=game_bahuang_lode_stopGatherRefreshLode, src=pid_rpc, management_plugin_name=game_bahuang_lode, auth=rw]
export const TestStopGatherRefreshLode = async (_eventName: string, arg: any) => {
    await env.dbMgr.write(async (tr: Tr) => {
            let param = new stopArg();
            param.list = arg.list;
            return await stopGatherRefreshLode(tr,Number(arg.rid),param);
    });
};
```

```ts
//注意：stopArg的结构为：
struct stopArg{
    /** 可能同时结算多个矿脉采集,一次性矿传入矿脉ID,刷新类型矿脉传入采集下标 */
    list:[u32],
}
```