import { Tr } from "pi_ucore/db/mgr";
import { getCfg, getAllCfg, writes } from "pi_common_tools/util/db_tool";
import { costProps, sendAwards } from 'pi_award/api';
import { read, write } from "pi_common_tools/util/db_tool";
import { LingBaoInstance, PlayerLingBaoDB, StarUpConsume, OperationError } from "game_special_equip/struct/LingBaoSystem";

import { LingBaoCfg } from "game_special_equip/xls/lingbao/lingbao_base.struct";
import { StarCfg } from "game_special_equip/xls/lingbao/lingbao_star.struct";
import { LingBaoChip } from "game_special_equip/xls/lingbao/lingbao_fragment.struct";

//-----------------------------------------------------------------------
// 灵宝系统API接口
//-----------------------------------------------------------------------
/**
 * @name 执行灵宝解锁操作
 * @param tr 事务对象
 * @param rid 玩家唯一rid
 * @param instanceId 灵宝实例ID
 */
export const unlockLingBao = async (tr: Tr, rid: number, instanceId: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;
    if(db.instances.has(instanceId))return {r : false,msg : "已经解锁灵宝"};       //已经解锁了灵宝了
    let baseCfgInfo = getCfg(getCfg,instanceId);
    if(!baseCfgInfo)return {r : false,msg : "参数错误"};

    let instance = new LingBaoInstance();
    instance.special_instance_id = instanceId;
    instance.star_level = 0;
    instance.hero_id = 0;
    db.instances.set(instance.special_instance_id,instance);
    await write(tr, PlayerLingBaoDB, rid, db);
    return true;
}


/**
 * @name 执行灵宝升星操作
 * @param tr 事务对象
 * @param rid 玩家唯一rid
 * @param instanceId 灵宝实例ID
 */
export const starUpLingBao = async (tr: Tr, rid: number, instanceId: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;
    if(!db.instances.has(instanceId)){
        return {r : false,msg : "未解锁灵宝"}     //未解锁灵宝
    }
    let instance = db.instances.get(instanceId);

    let cfgInfo = getCfg(StarCfg,instance.star_level);
    if(!cfgInfo.next){
        return {r : false,msg : "星级已达满级"}
    }

    // 扣除消耗材料
    const costResult = await costProps(tr, rid, []);
    if (!costResult) {
        return {r : false,msg : "材料不足"}
    }
    // 执行升星
    instance.star_level += 1;
    await write(tr, PlayerLingBaoDB, rid, db);
    
    return true;
}


/**
 * @name 装备灵宝到英雄
 * @param tr 事务对象
 * @param rid 玩家唯一rid
 * @param heroId 英雄ID
 * @param instanceId 灵宝实例ID
 */
export const equipToHero = async (tr: Tr, rid: number, heroId: number, instanceId: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;    
    if(!db.instances.has(instanceId)){
        return {r : false,msg : "未解锁灵宝"}     //未解锁灵宝
    }

    // 检查灵宝是否已装备
    let lingbao = db.instances.get(instanceId);

    if(lingbao.hero_id){
        // return {r : false,msg : "灵宝已经装备"}     //未解锁灵宝
        db.hero_equips.delete(lingbao.hero_id);        //删除当前灵宝匹配的卡牌
    }

    //绑定到当前卡牌
    lingbao.hero_id = heroId;
    db.hero_equips.set(lingbao.hero_id,instanceId);

    await write(tr, PlayerLingBaoDB, rid, db);
    return { r : true, msg : 'ok' } ;
}

/**
 * @name 卸下灵宝
 * @param tr 事务对象
 * @param rid 玩家唯一rid
 * @param heroId 英雄ID
 */
export const unequipFromHero = async (tr: Tr, rid: number, heroId: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;

    if(!db.hero_equips.has(heroId)){
        return {r : false,msg : "未装备灵宝"}     //未装备灵宝
    }

    // 
    let instanceId = db.hero_equips.get(heroId);
    // 检查灵宝
    let lingbao = db.instances.get(instanceId);

    if(lingbao.hero_id !== heroId){
        return {r : false,msg : "数据错误"}     //未装备灵宝
    }

    lingbao.hero_id = 0;
    db.hero_equips.delete(heroId);

    await write(tr, PlayerLingBaoDB, rid, db);
    return true;
}


