import { Tr } from "pi_ucore/db/mgr";
import { Env } from "pi_ucore/db/env";
import { getCurrentRid } from "pi_common_tools/main";
import { read, write } from "pi_common_tools/util/db_tool";
import { LingBaoInstance, PlayerLingBaoDB, StarUpConsume, OperationError } from "game_special_equip/struct/LingBaoSystem";
import { starUpLingBao, equipToHero, unequipFromHero } from '../api';

//-----------------------------------------------------------------------
// 灵宝系统RPC接口
//-----------------------------------------------------------------------

// #[rpc=rpcServer, src=*,rpcWrapper=read,rpcMode=check]
export const checkStarUpConditionsRpc = async (tr: Tr, rid: number, instanceId: number) => {
    const db = await read(tr, PlayerLingBaoDB, rid) as PlayerLingBaoDB;
    const instance = db.instances.get(instanceId);
    
    // 校验升星条件
    const canStarUp = !!instance && 
        instance.star_level < instance.max_star &&
        db.hero_equips.values().every(equip => equip.equip_instance_id !== instanceId);
    
    return { canStarUp, requiredLevel: instance?.star_level ? instance.star_level + 1 : 0 };
}




// 灵宝升星
// #[rpc=rpcServer, src=*, rpcWrapper=write]
export const executeStarUpRpc = async (tr: Tr, rid: number, instanceId: number) => {
    if(isNaN(rid))return false;
    const result = await starUpLingBao(tr, rid, instanceId);
    return result;
}

//穿灵宝
// #[rpc=rpcServer, src=*,rpcWrapper=write]
export const equipLingBaoRpc = async (tr: Tr, rid: number, heroId: number, instanceId: number) => {
    if(isNaN(rid))return false;
    // 执行远程装备操作
    const result = await equipToHero(tr, rid, heroId, instanceId);
    return result;
}

// #[rpc=rpcServer, src=*,rpcMode=remote, rpcWrapper=write]
export const unequipLingBaoRpc = async (tr: Tr, rid: number, heroId: number) => {
    if(isNaN(rid))return false;
    return await unequipFromHero(tr, rid, heroId);
}
